@@ -5,11 +5,11 @@ from collections import OrderedDict
 
 from anasymod.sim.sim import Simulator
 from anasymod.util import call
-from anasymod.targets import SimulationTarget
+from anasymod.targets import CPUTarget
 from anasymod.config import EmuConfig
 
 class XceliumSimulator(Simulator):
-    def __init__(self, target: SimulationTarget):
+    def __init__(self, target: CPUTarget):
         super().__init__( target=target)
         self.unit = None
         self.id = None
@@ -22,6 +22,7 @@ class XceliumSimulator(Simulator):
         cmd = []
         cmd += [self.cfg.xcelium_config.xrun]
         if "ifxxcelium" in self.cfg.xcelium_config.xrun:
+            cmd += self.target.prj_cfg.xcelium_config.lsf_opts.split()
             cmd += ['inicio']
             if self.unit:
                 cmd += ["-unit", self.unit]
@@ -73,6 +74,11 @@ class XceliumSimulator(Simulator):
             for src in sources.files:
                 cmd.append(src)
 
+        # add HDL sources for functional models
+        for sources in self.target.content.functional_models:
+            for src in sources.gen_files:
+                cmd.append(src)
+
         # add VHDL source files
         # TODO: is it actually necessary to consolidate makelib commands together?  if subsequent makelib commands
         # append rather than replace files, then it should be OK (and simpler) to have a separate makelib for
@@ -88,7 +94,10 @@ class XceliumSimulator(Simulator):
             libraries[library] += files
 
         for library, sources in libraries.items():
-            cmd += ['-makelib', library]
+            if library is not None:
+                cmd += ['-makelib', library]
+            else:
+                cmd += ['-makelib']
             cmd += sources
             cmd += ['-endlib']
 
@@ -110,6 +119,8 @@ class XceliumSimulator(Simulator):
                 cmd += ["-unit", self.unit ]
             if self.id:
                 cmd += ["-id", self.id ]
+            else:
+                self.id = "xcelium"
 
             print(cmd)
             call(cmd, cwd=self.cfg.build_root)
