@@ -7,7 +7,7 @@ from anasymod.enums import ConfigSections, FPGASimCtrl, ResultFileTypes
 from anasymod.structures.structure_config import StructureConfig
 from anasymod.structures.module_top import ModuleTop
 from anasymod.structures.module_clk_manager import ModuleClkManager
-from anasymod.sources import VerilogSource, VerilogHeader
+from anasymod.sources import VerilogSource, VerilogHeader, FirmwareFile
 from anasymod.sim_ctrl.uart_ctrlinfra import UARTControlInfrastructure
 from anasymod.sim_ctrl.vio_ctrlinfra import VIOControlInfrastructure
 from anasymod.structures.module_traceport import ModuleTracePort
@@ -17,6 +17,7 @@ from anasymod.sim_ctrl.vio_ctrlapi import VIOCtrlApi
 from anasymod.sim_ctrl.uart_ctrlapi import UARTCtrlApi
 from anasymod.files import anasymod_root, anasymod_header
 from anasymod.util import expand_searchpaths
+from anasymod.structures.firmware_gpio import FirmwareGPIO
 
 from anasymod.structures.module_viosimctrl import ModuleVIOSimCtrl
 
@@ -133,6 +134,22 @@ class Target():
         self.content.verilog_sources += [VerilogSource(files=timemanager_path,
                                                        name='gen_time_manager')]
 
+    def gen_firmware(self):
+        # Generate firmware
+        gpio_fw = FirmwareGPIO(scfg=self.str_cfg)
+
+        # Write header code
+        gpio_hdr = os.path.join(self.prj_cfg.build_root, 'gpio_funcs.h')
+        with open(gpio_hdr, 'w') as f:
+            f.write(gpio_fw.hdr_text)
+        self.content.firmware_files += [FirmwareFile(files=gpio_hdr, name='gpio_hdr')]
+
+        # Write implementation code
+        gpio_src = os.path.join(self.prj_cfg.build_root, 'gpio_funcs.c')
+        with open(gpio_src, 'w') as f:
+            f.write(gpio_fw.src_text)
+        self.content.firmware_files += [FirmwareFile(files=gpio_src, name='gpio_src')]
+
     @property
     def project_root(self):
         return os.path.join(self.prj_cfg.build_root, self.prj_cfg.vivado_config.project_name)
@@ -271,6 +288,8 @@ class Content():
         """:type : List[Define]"""
         self.edif_files = []
         """:type : List[EDIFFile]"""
+        self.firmware_files = []
+        """:type : List[FirmwareFile]"""
         self.xci_files = []
         """:type : List[XCIFile]"""
         self.xdc_files = []
